EXPORTS
	?NewL@CSecureSocket@@SAPAV1@AAVRSocket@@ABVTDesC16@@@Z @ 1 NONAME ; public: static class CSecureSocket * __cdecl CSecureSocket::NewL(class RSocket &,class TDesC16 const &)
	?Unload@CSecureSocketLibraryLoader@@SAXXZ @ 2 NONAME ; public: static void __cdecl CSecureSocketLibraryLoader::Unload(void)
	?AvailableCipherSuites@CSecureSocket@@QAEHAAVTDes8@@@Z @ 3 NONAME ; public: int __thiscall CSecureSocket::AvailableCipherSuites(class TDes8 &)
	?CancelAll@CSecureSocket@@QAEXXZ @ 4 NONAME ; public: void __thiscall CSecureSocket::CancelAll(void)
	?CancelHandshake@CSecureSocket@@QAEXXZ @ 5 NONAME ; public: void __thiscall CSecureSocket::CancelHandshake(void)
	?CancelRecv@CSecureSocket@@QAEXXZ @ 6 NONAME ; public: void __thiscall CSecureSocket::CancelRecv(void)
	?CancelSend@CSecureSocket@@QAEXXZ @ 7 NONAME ; public: void __thiscall CSecureSocket::CancelSend(void)
	?ClientCert@CSecureSocket@@QAEPBVCX509Certificate@@XZ @ 8 NONAME ; public: class CX509Certificate const * __thiscall CSecureSocket::ClientCert(void)
	?ClientCertMode@CSecureSocket@@QAE?AW4TClientCertMode@@XZ @ 9 NONAME ; public: enum TClientCertMode  __thiscall CSecureSocket::ClientCertMode(void)
	?Close@CSecureSocket@@QAEXXZ @ 10 NONAME ; public: void __thiscall CSecureSocket::Close(void)
	?CurrentCipherSuite@CSecureSocket@@QAEHAAVTDes8@@@Z @ 11 NONAME ; public: int __thiscall CSecureSocket::CurrentCipherSuite(class TDes8 &)
	?DialogMode@CSecureSocket@@QAE?AW4TDialogMode@@XZ @ 12 NONAME ; public: enum TDialogMode  __thiscall CSecureSocket::DialogMode(void)
	?FlushSessionCache@CSecureSocket@@QAEXXZ @ 13 NONAME ; public: void __thiscall CSecureSocket::FlushSessionCache(void)
	?GetOpt@CSecureSocket@@QAEHIIAAH@Z @ 14 NONAME ; public: int __thiscall CSecureSocket::GetOpt(unsigned int,unsigned int,int &)
	?GetOpt@CSecureSocket@@QAEHIIAAVTDes8@@@Z @ 15 NONAME ; public: int __thiscall CSecureSocket::GetOpt(unsigned int,unsigned int,class TDes8 &)
	?Protocol@CSecureSocket@@QAEHAAVTDes16@@@Z @ 16 NONAME ; public: int __thiscall CSecureSocket::Protocol(class TDes16 &)
	?Recv@CSecureSocket@@QAEXAAVTDes8@@AAVTRequestStatus@@@Z @ 17 NONAME ; public: void __thiscall CSecureSocket::Recv(class TDes8 &,class TRequestStatus &)
	?RecvOneOrMore@CSecureSocket@@QAEXAAVTDes8@@AAVTRequestStatus@@AAV?$TPckgBuf@H@@@Z @ 18 NONAME ; public: void __thiscall CSecureSocket::RecvOneOrMore(class TDes8 &,class TRequestStatus &,class TPckgBuf<int> &)
	?RenegotiateHandshake@CSecureSocket@@QAEXAAVTRequestStatus@@@Z @ 19 NONAME ; public: void __thiscall CSecureSocket::RenegotiateHandshake(class TRequestStatus &)
	?Send@CSecureSocket@@QAEXABVTDesC8@@AAVTRequestStatus@@@Z @ 20 NONAME ; public: void __thiscall CSecureSocket::Send(class TDesC8 const &,class TRequestStatus &)
	?Send@CSecureSocket@@QAEXABVTDesC8@@AAVTRequestStatus@@AAV?$TPckgBuf@H@@@Z @ 21 NONAME ; public: void __thiscall CSecureSocket::Send(class TDesC8 const &,class TRequestStatus &,class TPckgBuf<int> &)
	?ServerCert@CSecureSocket@@QAEPBVCX509Certificate@@XZ @ 22 NONAME ; public: class CX509Certificate const * __thiscall CSecureSocket::ServerCert(void)
	?SetAvailableCipherSuites@CSecureSocket@@QAEHABVTDesC8@@@Z @ 23 NONAME ; public: int __thiscall CSecureSocket::SetAvailableCipherSuites(class TDesC8 const &)
	?SetClientCert@CSecureSocket@@QAEHABVCX509Certificate@@@Z @ 24 NONAME ; public: int __thiscall CSecureSocket::SetClientCert(class CX509Certificate const &)
	?SetClientCertMode@CSecureSocket@@QAEHW4TClientCertMode@@@Z @ 25 NONAME ; public: int __thiscall CSecureSocket::SetClientCertMode(enum TClientCertMode)
	?SetDialogMode@CSecureSocket@@QAEHW4TDialogMode@@@Z @ 26 NONAME ; public: int __thiscall CSecureSocket::SetDialogMode(enum TDialogMode)
	?SetOpt@CSecureSocket@@QAEHIIABVTDesC8@@@Z @ 27 NONAME ; public: int __thiscall CSecureSocket::SetOpt(unsigned int,unsigned int,class TDesC8 const &)
	?SetOpt@CSecureSocket@@QAEHIIH@Z @ 28 NONAME ; public: int __thiscall CSecureSocket::SetOpt(unsigned int,unsigned int,int)
	?SetProtocol@CSecureSocket@@QAEHABVTDesC16@@@Z @ 29 NONAME ; public: int __thiscall CSecureSocket::SetProtocol(class TDesC16 const &)
	?SetServerCert@CSecureSocket@@QAEHABVCX509Certificate@@@Z @ 30 NONAME ; public: int __thiscall CSecureSocket::SetServerCert(class CX509Certificate const &)
	?StartClientHandshake@CSecureSocket@@QAEXAAVTRequestStatus@@@Z @ 31 NONAME ; public: void __thiscall CSecureSocket::StartClientHandshake(class TRequestStatus &)
	?StartServerHandshake@CSecureSocket@@QAEXAAVTRequestStatus@@@Z @ 32 NONAME ; public: void __thiscall CSecureSocket::StartServerHandshake(class TRequestStatus &)
	?NewL@CSecureSocket@@SAPAV1@AAVMGenericSecureSocket@@ABVTDesC16@@@Z @ 33 NONAME ; class CSecureSocket * CSecureSocket::NewL(class MGenericSecureSocket &, class TDesC16 const &)

